diff --git a/.Dockerfile b/.Dockerfile
deleted file mode 100644
index b5c205734..000000000
--- a/.Dockerfile
+++ /dev/null
@@ -1,8 +0,0 @@
-FROM gitpod/workspace-node
-
-# Install latest pnpm
-RUN curl -fsSL https://get.pnpm.io/install.sh | SHELL=`which bash` bash -
-
-# Install deno in gitpod
-RUN curl -fsSL https://deno.land/x/install/install.sh | sh
-RUN /home/gitpod/.deno/bin/deno completions bash > /home/gitpod/.bashrc.d/90-deno && echo 'export DENO_INSTALL="/home/gitpod/.deno"' >> /home/gitpod/.bashrc.d/90-deno && echo 'export PATH="$DENO_INSTALL/bin:$PATH"' >> /home/gitpod/.bashrc.d/90-deno
diff --git a/.changeset/early-ghosts-hang.md b/.changeset/early-ghosts-hang.md
deleted file mode 100644
index 41215d739..000000000
--- a/.changeset/early-ghosts-hang.md
+++ /dev/null
@@ -1,6 +0,0 @@
----
-'@astrojs/tailwind': patch
-'astro': patch
----
-
-The `@astrojs/tailwind` integration now creates a `tailwind.config.mjs` file by default
diff --git a/.changeset/forty-singers-ring.md b/.changeset/forty-singers-ring.md
new file mode 100644
index 000000000..bbb8a040d
--- /dev/null
+++ b/.changeset/forty-singers-ring.md
@@ -0,0 +1,5 @@
+---
+'astro': patch
+---
+
+Fixed an issue where the transitions router did not work within framework components.
diff --git a/.changeset/great-bears-watch.md b/.changeset/great-bears-watch.md
deleted file mode 100644
index ced76bad7..000000000
--- a/.changeset/great-bears-watch.md
+++ /dev/null
@@ -1,9 +0,0 @@
----
-'astro': patch
----
-
-Revert fix #8472
-
-[#8472](https://github.com/withastro/astro/pull/8472) caused some style files from previous pages to not be cleanly deleted on view transitions. For a discussion of a future fix for the original issue [#8144](https://github.com/withastro/astro/issues/8114) see [#8745](https://github.com/withastro/astro/pull/8745).
-
-
diff --git a/.changeset/heavy-elephants-tan.md b/.changeset/heavy-elephants-tan.md
deleted file mode 100644
index 4dc2b8579..000000000
--- a/.changeset/heavy-elephants-tan.md
+++ /dev/null
@@ -1,5 +0,0 @@
----
-'@astrojs/cloudflare': patch
----
-
-Adds `cloudflare:sockets` compile support
diff --git a/.changeset/large-clouds-sip.md b/.changeset/large-clouds-sip.md
deleted file mode 100644
index c271de43c..000000000
--- a/.changeset/large-clouds-sip.md
+++ /dev/null
@@ -1,5 +0,0 @@
----
-'astro': patch
----
-
-Fixed an issue on Windows where lowercase drive letters in current working directory led to missing scripts and styles.
diff --git a/.changeset/seven-seas-hide.md b/.changeset/seven-seas-hide.md
deleted file mode 100644
index 1b758f404..000000000
--- a/.changeset/seven-seas-hide.md
+++ /dev/null
@@ -1,5 +0,0 @@
----
-'astro': patch
----
-
-Fix flickering during view transitions
diff --git a/.changeset/sharp-insects-yawn.md b/.changeset/sharp-insects-yawn.md
deleted file mode 100644
index 742517633..000000000
--- a/.changeset/sharp-insects-yawn.md
+++ /dev/null
@@ -1,5 +0,0 @@
----
-'astro': patch
----
-
-Make CSS chunk names less confusing
diff --git a/.changeset/tidy-bags-give.md b/.changeset/tidy-bags-give.md
deleted file mode 100644
index 9bf67c0e3..000000000
--- a/.changeset/tidy-bags-give.md
+++ /dev/null
@@ -1,5 +0,0 @@
----
-'@astrojs/cloudflare': patch
----
-
-Adds support for `node:crypto`
diff --git a/.changeset/unlucky-avocados-brake.md b/.changeset/unlucky-avocados-brake.md
new file mode 100644
index 000000000..b64fc24c7
--- /dev/null
+++ b/.changeset/unlucky-avocados-brake.md
@@ -0,0 +1,5 @@
+---
+'@astrojs/cloudflare': patch
+---
+
+fixes `AdvancedRuntime` & `DirectoryRuntime` types to work woth Cloudflare caches
diff --git a/.changeset/wise-lions-lay.md b/.changeset/wise-lions-lay.md
deleted file mode 100644
index 5718740fe..000000000
--- a/.changeset/wise-lions-lay.md
+++ /dev/null
@@ -1,5 +0,0 @@
----
-'astro': patch
----
-
-Fix transition attributes on islands
diff --git a/.changeset/young-taxis-battle.md b/.changeset/young-taxis-battle.md
deleted file mode 100644
index 66d0ad1d4..000000000
--- a/.changeset/young-taxis-battle.md
+++ /dev/null
@@ -1,5 +0,0 @@
----
-'astro': patch
----
-
-Fix an issue where HTML attributes do not render if getHTMLAttributes in an image service returns a Promise
\ No newline at end of file
diff --git a/.devcontainer/Dockerfile b/.devcontainer/Dockerfile
index de1541343..85a51017b 100644
--- a/.devcontainer/Dockerfile
+++ b/.devcontainer/Dockerfile
@@ -6,10 +6,6 @@ RUN npm install -g @playwright/test
# Install latest pnpm
RUN npm install -g pnpm
-# Install deno
-ENV DENO_INSTALL=/usr/local
-RUN curl -fsSL https://deno.land/x/install/install.sh | sh
-
RUN apt-get update && export DEBIAN_FRONTEND=noninteractive \
&& curl -sSL https://dl.google.com/linux/direct/google-chrome-stable_current_$(dpkg --print-architecture).deb -o /tmp/chrome.deb \
&& apt-get -y install /tmp/chrome.deb
diff --git a/.devcontainer/deno/devcontainer.json b/.devcontainer/deno/devcontainer.json
deleted file mode 100644
index 05b733527..000000000
--- a/.devcontainer/deno/devcontainer.json
+++ /dev/null
@@ -1,34 +0,0 @@
-{
- "name": "Deno",
- "build": {
- "dockerfile": "../examples.deno.Dockerfile"
- },
-
- "workspaceFolder": "/workspaces/astro/examples/deno",
-
- "portsAttributes": {
- "4321": {
- "label": "Application",
- "onAutoForward": "openPreview"
- }
- },
-
- "forwardPorts": [4321],
-
- "postCreateCommand": "pnpm install && cd /workspaces/astro && pnpm run build",
-
- "waitFor": "postCreateCommand",
-
- "postAttachCommand": {
- "Server": "pnpm start --host"
- },
-
- "customizations": {
- "codespaces": {
- "openFiles": ["src/pages/index.astro"]
- },
- "vscode": {
- "extensions": ["astro-build.astro-vscode", "esbenp.prettier-vscode"]
- }
- }
-}
diff --git a/.devcontainer/examples.deno.Dockerfile b/.devcontainer/examples.deno.Dockerfile
deleted file mode 100644
index e4526f1ac..000000000
--- a/.devcontainer/examples.deno.Dockerfile
+++ /dev/null
@@ -1,10 +0,0 @@
-FROM mcr.microsoft.com/devcontainers/javascript-node:0-18
-
-# Install latest pnpm
-RUN npm install -g pnpm
-
-# Install deno
-ENV DENO_INSTALL=/usr/local
-RUN curl -fsSL https://deno.land/x/install/install.sh | sh
-
-COPY example-welcome-message.txt /usr/local/etc/vscode-dev-containers/first-run-notice.txt
\ No newline at end of file
diff --git a/.github/workflows/ci.yml b/.github/workflows/ci.yml
index aebf825ef..43da12b5d 100644
--- a/.github/workflows/ci.yml
+++ b/.github/workflows/ci.yml
@@ -133,11 +133,6 @@ jobs:
node-version: ${{ matrix.NODE_VERSION }}
cache: "pnpm"
- - name: Use Deno
- uses: denoland/setup-deno@v1
- with:
- deno-version: v1.35.0
-
- name: Install dependencies
run: pnpm install
diff --git a/.github/workflows/test-hosts.yml b/.github/workflows/test-hosts.yml
index 906e35aa4..c60d80e31 100644
--- a/.github/workflows/test-hosts.yml
+++ b/.github/workflows/test-hosts.yml
@@ -11,8 +11,6 @@ env:
VERCEL_ORG_ID: ${{ secrets.VERCEL_TEST_ORG_ID }}
VERCEL_PROJECT_ID: ${{ secrets.VERCEL_TEST_PROJECT_ID }}
VERCEL_TOKEN: ${{ secrets.VERCEL_TEST_TOKEN }}
- NETLIFY_SITE_ID: ${{ secrets.NETLIFY_TEST_SITE_ID }}
- NETLIFY_AUTH_TOKEN: ${{ secrets.NETLIFY_TEST_AUTH_TOKEN }}
FORCE_COLOR: true
jobs:
@@ -34,22 +32,20 @@ jobs:
- name: Install dependencies
run: pnpm install
+
+ - name: Build Astro
+ run: pnpm turbo build --filter astro --filter @astrojs/vercel
- - name: Install Hosts CLIs
- run: pnpm install --global netlify-cli vercel
-
- - name: Deploy Vercel
+ - name: Build test project
working-directory: ./packages/integrations/vercel/test/hosted/hosted-astro-project
run:
pnpm run build
- vercel --prod --prebuilt
-
- - name: Deploy Netlify
- working-directory: ./packages/integrations/netlify/test/hosted/hosted-astro-project
+
+ - name: Deploy to Vercel
+ working-directory: ./packages/integrations/vercel/test/hosted/hosted-astro-project
run:
- pnpm run build
- netlify deploy --prod
+ pnpm dlx vercel --prod --prebuilt
- - name: Test both hosts
+ - name: Test
run:
pnpm run test:e2e:hosts
diff --git a/.gitpod.yml b/.gitpod.yml
index 28e02e923..367ddf4fe 100644
--- a/.gitpod.yml
+++ b/.gitpod.yml
@@ -1,6 +1,4 @@
---
-image:
- file: .Dockerfile
# Commands to start on workspace startup
tasks:
- before: |
diff --git a/.gitpod/gitpod-setup.sh b/.gitpod/gitpod-setup.sh
index 6186117fe..b1ba15d2d 100755
--- a/.gitpod/gitpod-setup.sh
+++ b/.gitpod/gitpod-setup.sh
@@ -3,6 +3,9 @@
# Convert context URL to an array
mapfile -t CONTEXT_URL_ITEMS < <(echo "$GITPOD_WORKSPACE_CONTEXT_URL" | tr '/' '\n')
+# Install latest pnpm
+curl -fsSL https://get.pnpm.io/install.sh | SHELL=`which bash` bash -
+
# Check if Gitpod started from a specific example directory in the repository
if [ "${CONTEXT_URL_ITEMS[7]}" = "examples" ]; then
EXAMPLE_PROJECT=${CONTEXT_URL_ITEMS[8]}
diff --git a/README.md b/README.md
index c49b4760e..3ec82bbfd 100644
--- a/README.md
+++ b/README.md
@@ -52,8 +52,6 @@ Join us on [Discord](https://astro.build/chat) to meet other maintainers. We'll
| [@astrojs/svelte](packages/integrations/svelte) | [![astro version](https://img.shields.io/npm/v/@astrojs/svelte.svg?label=%20)](packages/integrations/svelte/CHANGELOG.md) |
| [@astrojs/vue](packages/integrations/vue) | [![astro version](https://img.shields.io/npm/v/@astrojs/vue.svg?label=%20)](packages/integrations/vue/CHANGELOG.md) |
| [@astrojs/lit](packages/integrations/lit) | [![astro version](https://img.shields.io/npm/v/@astrojs/lit.svg?label=%20)](packages/integrations/lit/CHANGELOG.md) |
-| [@astrojs/deno](packages/integrations/deno) | [![astro version](https://img.shields.io/npm/v/@astrojs/deno.svg?label=%20)](packages/integrations/deno/CHANGELOG.md) |
-| [@astrojs/netlify](packages/integrations/netlify) | [![astro version](https://img.shields.io/npm/v/@astrojs/netlify.svg?label=%20)](packages/integrations/netlify/CHANGELOG.md) |
| [@astrojs/node](packages/integrations/node) | [![astro version](https://img.shields.io/npm/v/@astrojs/node.svg?label=%20)](packages/integrations/node/CHANGELOG.md) |
| [@astrojs/vercel](packages/integrations/vercel) | [![astro version](https://img.shields.io/npm/v/@astrojs/vercel.svg?label=%20)](packages/integrations/vercel/CHANGELOG.md) |
| [@astrojs/cloudflare](packages/integrations/cloudflare) | [![astro version](https://img.shields.io/npm/v/@astrojs/cloudflare.svg?label=%20)](packages/integrations/cloudflare/CHANGELOG.md) |
diff --git a/examples/basics/package.json b/examples/basics/package.json
index 912e95290..2ee97a028 100644
--- a/examples/basics/package.json
+++ b/examples/basics/package.json
@@ -11,6 +11,6 @@
"astro": "astro"
},
"dependencies": {
- "astro": "^3.2.3"
+ "astro": "^3.2.4"
}
}
diff --git a/examples/blog/package.json b/examples/blog/package.json
index 55e083973..50a5ef88f 100644
--- a/examples/blog/package.json
+++ b/examples/blog/package.json
@@ -14,6 +14,6 @@
"@astrojs/mdx": "^1.1.1",
"@astrojs/rss": "^3.0.0",
"@astrojs/sitemap": "^3.0.1",
- "astro": "^3.2.3"
+ "astro": "^3.2.4"
}
}
diff --git a/examples/component/package.json b/examples/component/package.json
index 701f1d180..5bef35246 100644
--- a/examples/component/package.json
+++ b/examples/component/package.json
@@ -15,7 +15,7 @@
],
"scripts": {},
"devDependencies": {
- "astro": "^3.2.3"
+ "astro": "^3.2.4"
},
"peerDependencies": {
"astro": "^2.0.0-beta.0"
diff --git a/examples/framework-alpine/package.json b/examples/framework-alpine/package.json
index 732152d0b..a1e63670a 100644
--- a/examples/framework-alpine/package.json
+++ b/examples/framework-alpine/package.json
@@ -14,6 +14,6 @@
"@astrojs/alpinejs": "^0.3.1",
"@types/alpinejs": "^3.7.2",
"alpinejs": "^3.12.3",
- "astro": "^3.2.3"
+ "astro": "^3.2.4"
}
}
diff --git a/examples/framework-lit/package.json b/examples/framework-lit/package.json
index 407227d7f..61fd0d1fe 100644
--- a/examples/framework-lit/package.json
+++ b/examples/framework-lit/package.json
@@ -13,7 +13,7 @@
"dependencies": {
"@astrojs/lit": "^3.0.1",
"@webcomponents/template-shadowroot": "^0.2.1",
- "astro": "^3.2.3",
+ "astro": "^3.2.4",
"lit": "^2.8.0"
}
}
diff --git a/examples/framework-multiple/package.json b/examples/framework-multiple/package.json
index 48cdd3aa5..f05c46153 100644
--- a/examples/framework-multiple/package.json
+++ b/examples/framework-multiple/package.json
@@ -16,7 +16,7 @@
"@astrojs/solid-js": "^3.0.2",
"@astrojs/svelte": "^4.0.3",
"@astrojs/vue": "^3.0.1",
- "astro": "^3.2.3",
+ "astro": "^3.2.4",
"preact": "^10.17.1",
"react": "^18.2.0",
"react-dom": "^18.2.0",
diff --git a/examples/framework-preact/package.json b/examples/framework-preact/package.json
index f57093b82..9b5dbff2e 100644
--- a/examples/framework-preact/package.json
+++ b/examples/framework-preact/package.json
@@ -13,7 +13,7 @@
"dependencies": {
"@astrojs/preact": "^3.0.1",
"@preact/signals": "^1.2.1",
- "astro": "^3.2.3",
+ "astro": "^3.2.4",
"preact": "^10.17.1"
}
}
diff --git a/examples/framework-react/package.json b/examples/framework-react/package.json
index fc5c09440..1357ceecf 100644
--- a/examples/framework-react/package.json
+++ b/examples/framework-react/package.json
@@ -14,7 +14,7 @@
"@astrojs/react": "^3.0.3",
"@types/react": "^18.2.21",
"@types/react-dom": "^18.2.7",
- "astro": "^3.2.3",
+ "astro": "^3.2.4",
"react": "^18.2.0",
"react-dom": "^18.2.0"
}
diff --git a/examples/framework-solid/package.json b/examples/framework-solid/package.json
index 652e66209..23e5c0a43 100644
--- a/examples/framework-solid/package.json
+++ b/examples/framework-solid/package.json
@@ -12,7 +12,7 @@
},
"dependencies": {
"@astrojs/solid-js": "^3.0.2",
- "astro": "^3.2.3",
+ "astro": "^3.2.4",
"solid-js": "^1.7.11"
}
}
diff --git a/examples/framework-svelte/package.json b/examples/framework-svelte/package.json
index cd6fcc4b4..964198dac 100644
--- a/examples/framework-svelte/package.json
+++ b/examples/framework-svelte/package.json
@@ -12,7 +12,7 @@
},
"dependencies": {
"@astrojs/svelte": "^4.0.3",
- "astro": "^3.2.3",
+ "astro": "^3.2.4",
"svelte": "^4.2.0"
}
}
diff --git a/examples/framework-vue/package.json b/examples/framework-vue/package.json
index c2a6900d0..891957532 100644
--- a/examples/framework-vue/package.json
+++ b/examples/framework-vue/package.json
@@ -12,7 +12,7 @@
},
"dependencies": {
"@astrojs/vue": "^3.0.1",
- "astro": "^3.2.3",
+ "astro": "^3.2.4",
"vue": "^3.3.4"
}
}
diff --git a/examples/hackernews/package.json b/examples/hackernews/package.json
index 01e390b65..f52895da1 100644
--- a/examples/hackernews/package.json
+++ b/examples/hackernews/package.json
@@ -12,6 +12,6 @@
},
"dependencies": {
"@astrojs/node": "^6.0.3",
- "astro": "^3.2.3"
+ "astro": "^3.2.4"
}
}
diff --git a/examples/integration/index.ts b/examples/integration/index.ts
index 8c6cb35bf..54d917e78 100644
--- a/examples/integration/index.ts
+++ b/examples/integration/index.ts
@@ -10,9 +10,9 @@ export default function createIntegration(): AstroIntegration {
// See the @astrojs/react integration for an example
// https://github.com/withastro/astro/blob/main/packages/integrations/react/src/index.ts
},
- 'astro:build:setup': ({ config, updateConfig }) => {
- // See the @astrojs/netlify integration for an example
- // https://github.com/withastro/astro/blob/main/packages/integrations/netlify/src/integration-functions.ts
+ 'astro:build:setup': ({ pages, updateConfig }) => {
+ // See the @astrojs/lit integration for an example
+ // https://github.com/withastro/astro/blob/main/packages/integrations/lit/src/index.ts
},
'astro:build:done': ({ dir, routes }) => {
// See the @astrojs/partytown integration for an example
diff --git a/examples/integration/package.json b/examples/integration/package.json
index 01b9cba09..1035307c9 100644
--- a/examples/integration/package.json
+++ b/examples/integration/package.json
@@ -15,7 +15,7 @@
],
"scripts": {},
"devDependencies": {
- "astro": "^3.2.3"
+ "astro": "^3.2.4"
},
"peerDependencies": {
"astro": "^2.0.0-beta.0"
diff --git a/examples/middleware/package.json b/examples/middleware/package.json
index e2c640532..af73d9a2f 100644
--- a/examples/middleware/package.json
+++ b/examples/middleware/package.json
@@ -13,7 +13,7 @@
},
"dependencies": {
"@astrojs/node": "^6.0.3",
- "astro": "^3.2.3",
+ "astro": "^3.2.4",
"html-minifier": "^4.0.0"
}
}
diff --git a/examples/minimal/package.json b/examples/minimal/package.json
index eb852999f..ec5e64730 100644
--- a/examples/minimal/package.json
+++ b/examples/minimal/package.json
@@ -11,6 +11,6 @@
"astro": "astro"
},
"dependencies": {
- "astro": "^3.2.3"
+ "astro": "^3.2.4"
}
}
diff --git a/examples/non-html-pages/package.json b/examples/non-html-pages/package.json
index 7655413b5..abd245426 100644
--- a/examples/non-html-pages/package.json
+++ b/examples/non-html-pages/package.json
@@ -11,6 +11,6 @@
"astro": "astro"
},
"dependencies": {
- "astro": "^3.2.3"
+ "astro": "^3.2.4"
}
}
diff --git a/examples/portfolio/package.json b/examples/portfolio/package.json
index 058b8a1fc..70222641c 100644
--- a/examples/portfolio/package.json
+++ b/examples/portfolio/package.json
@@ -11,6 +11,6 @@
"astro": "astro"
},
"dependencies": {
- "astro": "^3.2.3"
+ "astro": "^3.2.4"
}
}
diff --git a/examples/ssr/package.json b/examples/ssr/package.json
index 3873a6098..cc14addca 100644
--- a/examples/ssr/package.json
+++ b/examples/ssr/package.json
@@ -14,7 +14,7 @@
"dependencies": {
"@astrojs/node": "^6.0.3",
"@astrojs/svelte": "^4.0.3",
- "astro": "^3.2.3",
+ "astro": "^3.2.4",
"svelte": "^4.2.0"
}
}
diff --git a/examples/view-transitions/package.json b/examples/view-transitions/package.json
index 63afa93a2..5e2e22797 100644
--- a/examples/view-transitions/package.json
+++ b/examples/view-transitions/package.json
@@ -10,8 +10,8 @@
"astro": "astro"
},
"devDependencies": {
- "@astrojs/tailwind": "^5.0.1",
+ "@astrojs/tailwind": "^5.0.2",
"@astrojs/node": "^6.0.3",
- "astro": "^3.2.3"
+ "astro": "^3.2.4"
}
}
diff --git a/examples/with-markdoc/package.json b/examples/with-markdoc/package.json
index 47abbe3d7..c0651d428 100644
--- a/examples/with-markdoc/package.json
+++ b/examples/with-markdoc/package.json
@@ -12,6 +12,6 @@
},
"dependencies": {
"@astrojs/markdoc": "^0.5.2",
- "astro": "^3.2.3"
+ "astro": "^3.2.4"
}
}
diff --git a/examples/with-markdown-plugins/package.json b/examples/with-markdown-plugins/package.json
index fdf825dcb..e906c6b0b 100644
--- a/examples/with-markdown-plugins/package.json
+++ b/examples/with-markdown-plugins/package.json
@@ -12,7 +12,7 @@
},
"dependencies": {
"@astrojs/markdown-remark": "^3.2.1",
- "astro": "^3.2.3",
+ "astro": "^3.2.4",
"hast-util-select": "^5.0.5",
"rehype-autolink-headings": "^6.1.1",
"rehype-slug": "^5.1.0",
diff --git a/examples/with-markdown-shiki/package.json b/examples/with-markdown-shiki/package.json
index 0da01ebdd..38bff6525 100644
--- a/examples/with-markdown-shiki/package.json
+++ b/examples/with-markdown-shiki/package.json
@@ -11,6 +11,6 @@
"astro": "astro"
},
"dependencies": {
- "astro": "^3.2.3"
+ "astro": "^3.2.4"
}
}
diff --git a/examples/with-mdx/package.json b/examples/with-mdx/package.json
index a6d84a347..bb49a2847 100644
--- a/examples/with-mdx/package.json
+++ b/examples/with-mdx/package.json
@@ -13,7 +13,7 @@
"dependencies": {
"@astrojs/mdx": "^1.1.1",
"@astrojs/preact": "^3.0.1",
- "astro": "^3.2.3",
+ "astro": "^3.2.4",
"preact": "^10.17.1"
}
}
diff --git a/examples/with-nanostores/package.json b/examples/with-nanostores/package.json
index 9939e0779..f778810af 100644
--- a/examples/with-nanostores/package.json
+++ b/examples/with-nanostores/package.json
@@ -13,7 +13,7 @@
"dependencies": {
"@astrojs/preact": "^3.0.1",
"@nanostores/preact": "^0.5.0",
- "astro": "^3.2.3",
+ "astro": "^3.2.4",
"nanostores": "^0.9.3",
"preact": "^10.17.1"
}
diff --git a/examples/with-tailwindcss/package.json b/examples/with-tailwindcss/package.json
index f6b4f9d25..850de4d08 100644
--- a/examples/with-tailwindcss/package.json
+++ b/examples/with-tailwindcss/package.json
@@ -12,9 +12,9 @@
},
"dependencies": {
"@astrojs/mdx": "^1.1.1",
- "@astrojs/tailwind": "^5.0.1",
+ "@astrojs/tailwind": "^5.0.2",
"@types/canvas-confetti": "^1.6.0",
- "astro": "^3.2.3",
+ "astro": "^3.2.4",
"autoprefixer": "^10.4.15",
"canvas-confetti": "^1.6.0",
"postcss": "^8.4.28",
diff --git a/examples/with-vite-plugin-pwa/package.json b/examples/with-vite-plugin-pwa/package.json
index aafacac3a..c5eb71f8f 100644
--- a/examples/with-vite-plugin-pwa/package.json
+++ b/examples/with-vite-plugin-pwa/package.json
@@ -11,7 +11,7 @@
"astro": "astro"
},
"dependencies": {
- "astro": "^3.2.3",
+ "astro": "^3.2.4",
"vite-plugin-pwa": "0.16.4",
"workbox-window": "^7.0.0"
}
diff --git a/examples/with-vitest/package.json b/examples/with-vitest/package.json
index bcd760017..845ac2313 100644
--- a/examples/with-vitest/package.json
+++ b/examples/with-vitest/package.json
@@ -12,7 +12,7 @@
"test": "vitest"
},
"dependencies": {
- "astro": "^3.2.3",
+ "astro": "^3.2.4",
"vitest": "^0.34.2"
}
}
diff --git a/packages/astro/CHANGELOG.md b/packages/astro/CHANGELOG.md
index 0d48bc340..1273fc04d 100644
--- a/packages/astro/CHANGELOG.md
+++ b/packages/astro/CHANGELOG.md
@@ -1,5 +1,25 @@
# astro
+## 3.2.4
+
+### Patch Changes
+
+- [#8638](https://github.com/withastro/astro/pull/8638) [`160d1cd75`](https://github.com/withastro/astro/commit/160d1cd755e70af1d8ec294d01dd2cb32d60db50) Thanks [@florian-lefebvre](https://github.com/florian-lefebvre)! - The `@astrojs/tailwind` integration now creates a `tailwind.config.mjs` file by default
+
+- [#8767](https://github.com/withastro/astro/pull/8767) [`30de32436`](https://github.com/withastro/astro/commit/30de324361bc261956eb9fc08fe60a82ff602a9b) Thanks [@martrapp](https://github.com/martrapp)! - Revert fix #8472
+
+ [#8472](https://github.com/withastro/astro/pull/8472) caused some style files from previous pages to not be cleanly deleted on view transitions. For a discussion of a future fix for the original issue [#8144](https://github.com/withastro/astro/issues/8114) see [#8745](https://github.com/withastro/astro/pull/8745).
+
+- [#8741](https://github.com/withastro/astro/pull/8741) [`c4a7ec425`](https://github.com/withastro/astro/commit/c4a7ec4255e7acb9555cb8bb74ea13c5fbb2ac17) Thanks [@lilnasy](https://github.com/lilnasy)! - Fixed an issue on Windows where lowercase drive letters in current working directory led to missing scripts and styles.
+
+- [#8772](https://github.com/withastro/astro/pull/8772) [`c24f70d91`](https://github.com/withastro/astro/commit/c24f70d91601dd3a6b5a84f04d61824e775e9b44) Thanks [@martrapp](https://github.com/martrapp)! - Fix flickering during view transitions
+
+- [#8754](https://github.com/withastro/astro/pull/8754) [`93b092266`](https://github.com/withastro/astro/commit/93b092266febfad16a48575f8eee12d5910bf071) Thanks [@bluwy](https://github.com/bluwy)! - Make CSS chunk names less confusing
+
+- [#8776](https://github.com/withastro/astro/pull/8776) [`29cdfa024`](https://github.com/withastro/astro/commit/29cdfa024886dd581cb207586f7dfec6966bdd4e) Thanks [@martrapp](https://github.com/martrapp)! - Fix transition attributes on islands
+
+- [#8773](https://github.com/withastro/astro/pull/8773) [`eaed844ea`](https://github.com/withastro/astro/commit/eaed844ea8f2f52e0c9caa40bb3ec7377e10595f) Thanks [@sumimakito](https://github.com/sumimakito)! - Fix an issue where HTML attributes do not render if getHTMLAttributes in an image service returns a Promise
+
## 3.2.3
### Patch Changes
diff --git a/packages/astro/e2e/fixtures/view-transitions/src/components/ClickToNavigate.jsx b/packages/astro/e2e/fixtures/view-transitions/src/components/ClickToNavigate.jsx
new file mode 100644
index 000000000..db8cc25f3
--- /dev/null
+++ b/packages/astro/e2e/fixtures/view-transitions/src/components/ClickToNavigate.jsx
@@ -0,0 +1,5 @@
+import React from 'react';
+import { navigate } from "astro:transitions/client";
+export default function ClickToNavigate({ to, id }) {
+ return ;
+}
diff --git a/packages/astro/e2e/fixtures/view-transitions/src/pages/client-load.astro b/packages/astro/e2e/fixtures/view-transitions/src/pages/client-load.astro
new file mode 100644
index 000000000..f24d216be
--- /dev/null
+++ b/packages/astro/e2e/fixtures/view-transitions/src/pages/client-load.astro
@@ -0,0 +1,12 @@
+---
+import ClickToNavigate from "../components/ClickToNavigate.jsx"
+import { ViewTransitions } from "astro:transitions";
+---
+
+
+
+
+
+
+
+
diff --git a/packages/astro/e2e/view-transitions.test.js b/packages/astro/e2e/view-transitions.test.js
index 80342cb35..559592fba 100644
--- a/packages/astro/e2e/view-transitions.test.js
+++ b/packages/astro/e2e/view-transitions.test.js
@@ -753,6 +753,21 @@ test.describe('View Transitions', () => {
await expect(p, 'should have content').toHaveText('Page 1');
});
+ test('Use the client side router in framework components', async ({ page, astro }) => {
+ await page.goto(astro.resolveUrl('/client-load'));
+
+ // the button is set to naviagte() to /two
+ const button = page.locator('#react-client-load-navigate-button');
+
+ await expect(button, 'should have content').toHaveText('Navigate to `/two`');
+
+ await button.click();
+
+ const p = page.locator('#two');
+
+ await expect(p, 'should have content').toHaveText('Page 2');
+ });
+
test('body inline scripts do not re-execute on navigation', async ({ page, astro }) => {
const errors = [];
page.addListener('pageerror', (err) => {
diff --git a/packages/astro/package.json b/packages/astro/package.json
index 936ac2c36..745808d44 100644
--- a/packages/astro/package.json
+++ b/packages/astro/package.json
@@ -1,6 +1,6 @@
{
"name": "astro",
- "version": "3.2.3",
+ "version": "3.2.4",
"description": "Astro is a modern site builder with web best practices, performance, and DX front-of-mind.",
"type": "module",
"author": "withastro",
diff --git a/packages/astro/src/cli/add/index.ts b/packages/astro/src/cli/add/index.ts
index d47db0e99..f84f67f1e 100644
--- a/packages/astro/src/cli/add/index.ts
+++ b/packages/astro/src/cli/add/index.ts
@@ -74,7 +74,6 @@ const OFFICIAL_ADAPTER_TO_IMPORT_MAP: Record = {
vercel: '@astrojs/vercel/serverless',
cloudflare: '@astrojs/cloudflare',
node: '@astrojs/node',
- deno: '@astrojs/deno',
};
// Users might lack access to the global npm registry, this function
diff --git a/packages/integrations/cloudflare/CHANGELOG.md b/packages/integrations/cloudflare/CHANGELOG.md
index 9dd7772cc..c17ebb2d3 100644
--- a/packages/integrations/cloudflare/CHANGELOG.md
+++ b/packages/integrations/cloudflare/CHANGELOG.md
@@ -1,5 +1,17 @@
# @astrojs/cloudflare
+## 7.5.2
+
+### Patch Changes
+
+- [#8766](https://github.com/withastro/astro/pull/8766) [`054c5c644`](https://github.com/withastro/astro/commit/054c5c6447d79dd4ea7ab6ce0f9ec836abebd211) Thanks [@jadbox](https://github.com/jadbox)! - Adds `cloudflare:sockets` compile support
+
+- [#8788](https://github.com/withastro/astro/pull/8788) [`0ab6bad7d`](https://github.com/withastro/astro/commit/0ab6bad7dffd413c975ab00e545f8bc150f6a92f) Thanks [@alexanderniebuhr](https://github.com/alexanderniebuhr)! - Adds support for `node:crypto`
+
+- Updated dependencies [[`160d1cd75`](https://github.com/withastro/astro/commit/160d1cd755e70af1d8ec294d01dd2cb32d60db50), [`30de32436`](https://github.com/withastro/astro/commit/30de324361bc261956eb9fc08fe60a82ff602a9b), [`c4a7ec425`](https://github.com/withastro/astro/commit/c4a7ec4255e7acb9555cb8bb74ea13c5fbb2ac17), [`c24f70d91`](https://github.com/withastro/astro/commit/c24f70d91601dd3a6b5a84f04d61824e775e9b44), [`93b092266`](https://github.com/withastro/astro/commit/93b092266febfad16a48575f8eee12d5910bf071), [`29cdfa024`](https://github.com/withastro/astro/commit/29cdfa024886dd581cb207586f7dfec6966bdd4e), [`eaed844ea`](https://github.com/withastro/astro/commit/eaed844ea8f2f52e0c9caa40bb3ec7377e10595f)]:
+ - astro@3.2.4
+ - @astrojs/underscore-redirects@0.3.1
+
## 7.5.1
### Patch Changes
diff --git a/packages/integrations/cloudflare/README.md b/packages/integrations/cloudflare/README.md
index 9bae28c5a..7ca92152b 100644
--- a/packages/integrations/cloudflare/README.md
+++ b/packages/integrations/cloudflare/README.md
@@ -169,7 +169,7 @@ default: `false`
Whether or not to import `.wasm` files [directly as ES modules](https://github.com/WebAssembly/esm-integration/tree/main/proposals/esm-integration) using the `.wasm?module` import syntax.
-Add `wasmModuleImports: true` to `astro.config.mjs` to enable this functionality in both the Cloudflare build and the Astro dev server. Read more about [using Wasm modules](#use-wasm-modules)
+Add `wasmModuleImports: true` to `astro.config.mjs` to enable this functionality in both the Cloudflare build and the Astro dev server. Read more about [using Wasm modules](#use-wasm-modules).
```diff lang="js"
// astro.config.mjs
@@ -221,7 +221,7 @@ Currently supported bindings:
- [Cloudflare Workers KV](https://developers.cloudflare.com/kv/)
- [Cloudflare Durable Objects](https://developers.cloudflare.com/durable-objects/)
-You can access the runtime from Astro components through `Astro.locals` inside any .astro` file.
+You can access the runtime from Astro components through `Astro.locals` inside any `.astro` file.
```astro
---
diff --git a/packages/integrations/cloudflare/package.json b/packages/integrations/cloudflare/package.json
index b7ecc2c69..f9527bc76 100644
--- a/packages/integrations/cloudflare/package.json
+++ b/packages/integrations/cloudflare/package.json
@@ -1,7 +1,7 @@
{
"name": "@astrojs/cloudflare",
"description": "Deploy your site to Cloudflare Workers/Pages",
- "version": "7.5.1",
+ "version": "7.5.2",
"type": "module",
"types": "./dist/index.d.ts",
"author": "withastro",
@@ -48,7 +48,7 @@
"vite": "^4.4.9"
},
"peerDependencies": {
- "astro": "workspace:^3.2.3"
+ "astro": "workspace:^3.2.4"
},
"devDependencies": {
"@types/iarna__toml": "^2.0.2",
diff --git a/packages/integrations/cloudflare/src/entrypoints/server.advanced.ts b/packages/integrations/cloudflare/src/entrypoints/server.advanced.ts
index 957c1791d..c7c8e8466 100644
--- a/packages/integrations/cloudflare/src/entrypoints/server.advanced.ts
+++ b/packages/integrations/cloudflare/src/entrypoints/server.advanced.ts
@@ -1,4 +1,8 @@
-import type { Request as CFRequest, ExecutionContext } from '@cloudflare/workers-types';
+import type {
+ Request as CFRequest,
+ CacheStorage,
+ ExecutionContext,
+} from '@cloudflare/workers-types';
import type { SSRManifest } from 'astro';
import { App } from 'astro/app';
import { getProcessEnvProxy, isNode } from '../util.js';
@@ -16,7 +20,7 @@ export interface AdvancedRuntime {
waitUntil: (promise: Promise) => void;
env: Env & T;
cf: CFRequest['cf'];
- caches: typeof caches;
+ caches: CacheStorage;
};
}
@@ -50,7 +54,7 @@ export function createExports(manifest: SSRManifest) {
},
env: env,
cf: request.cf,
- caches: caches,
+ caches: caches as unknown as CacheStorage,
},
};
diff --git a/packages/integrations/cloudflare/src/entrypoints/server.directory.ts b/packages/integrations/cloudflare/src/entrypoints/server.directory.ts
index 3542279b0..6f573fe71 100644
--- a/packages/integrations/cloudflare/src/entrypoints/server.directory.ts
+++ b/packages/integrations/cloudflare/src/entrypoints/server.directory.ts
@@ -1,4 +1,4 @@
-import type { Request as CFRequest, EventContext } from '@cloudflare/workers-types';
+import type { Request as CFRequest, CacheStorage, EventContext } from '@cloudflare/workers-types';
import type { SSRManifest } from 'astro';
import { App } from 'astro/app';
import { getProcessEnvProxy, isNode } from '../util.js';
@@ -6,13 +6,12 @@ import { getProcessEnvProxy, isNode } from '../util.js';
if (!isNode) {
process.env = getProcessEnvProxy();
}
-
export interface DirectoryRuntime {
runtime: {
waitUntil: (promise: Promise) => void;
env: EventContext['env'] & T;
cf: CFRequest['cf'];
- caches: typeof caches;
+ caches: CacheStorage;
};
}
@@ -48,7 +47,7 @@ export function createExports(manifest: SSRManifest) {
},
env: context.env,
cf: request.cf,
- caches: caches,
+ caches: caches as unknown as CacheStorage,
},
};
diff --git a/packages/integrations/markdoc/package.json b/packages/integrations/markdoc/package.json
index e7e5eaee0..f24024362 100644
--- a/packages/integrations/markdoc/package.json
+++ b/packages/integrations/markdoc/package.json
@@ -75,7 +75,7 @@
"zod": "3.21.1"
},
"peerDependencies": {
- "astro": "workspace:^3.2.3"
+ "astro": "workspace:^3.2.4"
},
"devDependencies": {
"@astrojs/markdown-remark": "workspace:*",
diff --git a/packages/integrations/mdx/package.json b/packages/integrations/mdx/package.json
index 2e90eda93..8192ad4c0 100644
--- a/packages/integrations/mdx/package.json
+++ b/packages/integrations/mdx/package.json
@@ -51,7 +51,7 @@
"vfile": "^5.3.7"
},
"peerDependencies": {
- "astro": "workspace:^3.2.3"
+ "astro": "workspace:^3.2.4"
},
"devDependencies": {
"@types/chai": "^4.3.5",
diff --git a/packages/integrations/node/package.json b/packages/integrations/node/package.json
index 6b896706d..28cc2fe45 100644
--- a/packages/integrations/node/package.json
+++ b/packages/integrations/node/package.json
@@ -37,7 +37,7 @@
"server-destroy": "^1.0.1"
},
"peerDependencies": {
- "astro": "workspace:^3.2.3"
+ "astro": "workspace:^3.2.4"
},
"devDependencies": {
"@types/node": "^18.17.8",
diff --git a/packages/integrations/svelte/package.json b/packages/integrations/svelte/package.json
index 6efeca706..545bb666d 100644
--- a/packages/integrations/svelte/package.json
+++ b/packages/integrations/svelte/package.json
@@ -48,7 +48,7 @@
"vite": "^4.4.9"
},
"peerDependencies": {
- "astro": "workspace:^3.2.3",
+ "astro": "workspace:^3.2.4",
"svelte": "^3.55.0 || ^4.0.0"
},
"engines": {
diff --git a/packages/integrations/tailwind/CHANGELOG.md b/packages/integrations/tailwind/CHANGELOG.md
index 6f4431c21..5810ea59b 100644
--- a/packages/integrations/tailwind/CHANGELOG.md
+++ b/packages/integrations/tailwind/CHANGELOG.md
@@ -1,5 +1,14 @@
# @astrojs/tailwind
+## 5.0.2
+
+### Patch Changes
+
+- [#8638](https://github.com/withastro/astro/pull/8638) [`160d1cd75`](https://github.com/withastro/astro/commit/160d1cd755e70af1d8ec294d01dd2cb32d60db50) Thanks [@florian-lefebvre](https://github.com/florian-lefebvre)! - The `@astrojs/tailwind` integration now creates a `tailwind.config.mjs` file by default
+
+- Updated dependencies [[`160d1cd75`](https://github.com/withastro/astro/commit/160d1cd755e70af1d8ec294d01dd2cb32d60db50), [`30de32436`](https://github.com/withastro/astro/commit/30de324361bc261956eb9fc08fe60a82ff602a9b), [`c4a7ec425`](https://github.com/withastro/astro/commit/c4a7ec4255e7acb9555cb8bb74ea13c5fbb2ac17), [`c24f70d91`](https://github.com/withastro/astro/commit/c24f70d91601dd3a6b5a84f04d61824e775e9b44), [`93b092266`](https://github.com/withastro/astro/commit/93b092266febfad16a48575f8eee12d5910bf071), [`29cdfa024`](https://github.com/withastro/astro/commit/29cdfa024886dd581cb207586f7dfec6966bdd4e), [`eaed844ea`](https://github.com/withastro/astro/commit/eaed844ea8f2f52e0c9caa40bb3ec7377e10595f)]:
+ - astro@3.2.4
+
## 5.0.1
### Patch Changes
diff --git a/packages/integrations/tailwind/package.json b/packages/integrations/tailwind/package.json
index 17bca109f..b4fce54af 100644
--- a/packages/integrations/tailwind/package.json
+++ b/packages/integrations/tailwind/package.json
@@ -1,7 +1,7 @@
{
"name": "@astrojs/tailwind",
"description": "Use Tailwind CSS to style your Astro site",
- "version": "5.0.1",
+ "version": "5.0.2",
"type": "module",
"types": "./dist/index.d.ts",
"author": "withastro",
@@ -43,7 +43,7 @@
"vite": "^4.4.9"
},
"peerDependencies": {
- "astro": "workspace:^3.2.3",
+ "astro": "workspace:^3.2.4",
"tailwindcss": "^3.0.24"
},
"publishConfig": {
diff --git a/packages/integrations/vercel/package.json b/packages/integrations/vercel/package.json
index b10ec83df..ecca04a1a 100644
--- a/packages/integrations/vercel/package.json
+++ b/packages/integrations/vercel/package.json
@@ -61,7 +61,7 @@
"web-vitals": "^3.4.0"
},
"peerDependencies": {
- "astro": "workspace:^3.2.3"
+ "astro": "workspace:^3.2.4"
},
"devDependencies": {
"@types/set-cookie-parser": "^2.4.3",
diff --git a/packages/integrations/vercel/test/hosted/hosted-astro-project/src/env.d.ts b/packages/integrations/vercel/test/hosted/hosted-astro-project/src/env.d.ts
index f7cbe9c1d..f964fe0cf 100644
--- a/packages/integrations/vercel/test/hosted/hosted-astro-project/src/env.d.ts
+++ b/packages/integrations/vercel/test/hosted/hosted-astro-project/src/env.d.ts
@@ -1 +1 @@
-///
+///
diff --git a/packages/integrations/vue/package.json b/packages/integrations/vue/package.json
index f50cdd01d..496e38665 100644
--- a/packages/integrations/vue/package.json
+++ b/packages/integrations/vue/package.json
@@ -56,7 +56,7 @@
"vue": "^3.3.4"
},
"peerDependencies": {
- "astro": "workspace:^3.2.3",
+ "astro": "workspace:^3.2.4",
"vue": "^3.2.30"
},
"engines": {
diff --git a/pnpm-lock.yaml b/pnpm-lock.yaml
index 9a49bbf35..faec79f26 100644
--- a/pnpm-lock.yaml
+++ b/pnpm-lock.yaml
@@ -125,7 +125,7 @@ importers:
examples/basics:
dependencies:
astro:
- specifier: ^3.2.3
+ specifier: ^3.2.4
version: link:../../packages/astro
examples/blog:
@@ -140,13 +140,13 @@ importers:
specifier: ^3.0.1
version: link:../../packages/integrations/sitemap
astro:
- specifier: ^3.2.3
+ specifier: ^3.2.4
version: link:../../packages/astro
examples/component:
devDependencies:
astro:
- specifier: ^3.2.3
+ specifier: ^3.2.4
version: link:../../packages/astro
examples/framework-alpine:
@@ -161,7 +161,7 @@ importers:
specifier: ^3.12.3
version: 3.12.3
astro:
- specifier: ^3.2.3
+ specifier: ^3.2.4
version: link:../../packages/astro
examples/framework-lit:
@@ -173,7 +173,7 @@ importers:
specifier: ^0.2.1
version: 0.2.1
astro:
- specifier: ^3.2.3
+ specifier: ^3.2.4
version: link:../../packages/astro
lit:
specifier: ^2.8.0
@@ -197,7 +197,7 @@ importers:
specifier: ^3.0.1
version: link:../../packages/integrations/vue
astro:
- specifier: ^3.2.3
+ specifier: ^3.2.4
version: link:../../packages/astro
preact:
specifier: ^10.17.1
@@ -227,7 +227,7 @@ importers:
specifier: ^1.2.1
version: 1.2.1(preact@10.17.1)
astro:
- specifier: ^3.2.3
+ specifier: ^3.2.4
version: link:../../packages/astro
preact:
specifier: ^10.17.1
@@ -245,7 +245,7 @@ importers:
specifier: ^18.2.7
version: 18.2.7
astro:
- specifier: ^3.2.3
+ specifier: ^3.2.4
version: link:../../packages/astro
react:
specifier: ^18.2.0
@@ -260,7 +260,7 @@ importers:
specifier: ^3.0.2
version: link:../../packages/integrations/solid
astro:
- specifier: ^3.2.3
+ specifier: ^3.2.4
version: link:../../packages/astro
solid-js:
specifier: ^1.7.11
@@ -272,7 +272,7 @@ importers:
specifier: ^4.0.3
version: link:../../packages/integrations/svelte
astro:
- specifier: ^3.2.3
+ specifier: ^3.2.4
version: link:../../packages/astro
svelte:
specifier: ^4.2.0
@@ -284,7 +284,7 @@ importers:
specifier: ^3.0.1
version: link:../../packages/integrations/vue
astro:
- specifier: ^3.2.3
+ specifier: ^3.2.4
version: link:../../packages/astro
vue:
specifier: ^3.3.4
@@ -296,13 +296,13 @@ importers:
specifier: ^6.0.3
version: link:../../packages/integrations/node
astro:
- specifier: ^3.2.3
+ specifier: ^3.2.4
version: link:../../packages/astro
examples/integration:
devDependencies:
astro:
- specifier: ^3.2.3
+ specifier: ^3.2.4
version: link:../../packages/astro
examples/middleware:
@@ -311,7 +311,7 @@ importers:
specifier: ^6.0.3
version: link:../../packages/integrations/node
astro:
- specifier: ^3.2.3
+ specifier: ^3.2.4
version: link:../../packages/astro
html-minifier:
specifier: ^4.0.0
@@ -320,19 +320,19 @@ importers:
examples/minimal:
dependencies:
astro:
- specifier: ^3.2.3
+ specifier: ^3.2.4
version: link:../../packages/astro
examples/non-html-pages:
dependencies:
astro:
- specifier: ^3.2.3
+ specifier: ^3.2.4
version: link:../../packages/astro
examples/portfolio:
dependencies:
astro:
- specifier: ^3.2.3
+ specifier: ^3.2.4
version: link:../../packages/astro
examples/ssr:
@@ -344,7 +344,7 @@ importers:
specifier: ^4.0.3
version: link:../../packages/integrations/svelte
astro:
- specifier: ^3.2.3
+ specifier: ^3.2.4
version: link:../../packages/astro
svelte:
specifier: ^4.2.0
@@ -356,10 +356,10 @@ importers:
specifier: ^6.0.3
version: link:../../packages/integrations/node
'@astrojs/tailwind':
- specifier: ^5.0.1
+ specifier: ^5.0.2
version: link:../../packages/integrations/tailwind
astro:
- specifier: ^3.2.3
+ specifier: ^3.2.4
version: link:../../packages/astro
examples/with-markdoc:
@@ -368,7 +368,7 @@ importers:
specifier: ^0.5.2
version: link:../../packages/integrations/markdoc
astro:
- specifier: ^3.2.3
+ specifier: ^3.2.4
version: link:../../packages/astro
examples/with-markdown-plugins:
@@ -377,7 +377,7 @@ importers:
specifier: ^3.2.1
version: link:../../packages/markdown/remark
astro:
- specifier: ^3.2.3
+ specifier: ^3.2.4
version: link:../../packages/astro
hast-util-select:
specifier: ^5.0.5
@@ -398,7 +398,7 @@ importers:
examples/with-markdown-shiki:
dependencies:
astro:
- specifier: ^3.2.3
+ specifier: ^3.2.4
version: link:../../packages/astro
examples/with-mdx:
@@ -410,7 +410,7 @@ importers:
specifier: ^3.0.1
version: link:../../packages/integrations/preact
astro:
- specifier: ^3.2.3
+ specifier: ^3.2.4
version: link:../../packages/astro
preact:
specifier: ^10.17.1
@@ -425,7 +425,7 @@ importers:
specifier: ^0.5.0
version: 0.5.0(nanostores@0.9.3)(preact@10.17.1)
astro:
- specifier: ^3.2.3
+ specifier: ^3.2.4
version: link:../../packages/astro
nanostores:
specifier: ^0.9.3
@@ -440,13 +440,13 @@ importers:
specifier: ^1.1.1
version: link:../../packages/integrations/mdx
'@astrojs/tailwind':
- specifier: ^5.0.1
+ specifier: ^5.0.2
version: link:../../packages/integrations/tailwind
'@types/canvas-confetti':
specifier: ^1.6.0
version: 1.6.0
astro:
- specifier: ^3.2.3
+ specifier: ^3.2.4
version: link:../../packages/astro
autoprefixer:
specifier: ^10.4.15
@@ -464,7 +464,7 @@ importers:
examples/with-vite-plugin-pwa:
dependencies:
astro:
- specifier: ^3.2.3
+ specifier: ^3.2.4
version: link:../../packages/astro
vite-plugin-pwa:
specifier: 0.16.4
@@ -476,7 +476,7 @@ importers:
examples/with-vitest:
dependencies:
astro:
- specifier: ^3.2.3
+ specifier: ^3.2.4
version: link:../../packages/astro
vitest:
specifier: ^0.34.2
diff --git a/packages/astro/src/transitions/router.ts b/packages/astro/src/transitions/router.ts
index 096f4abb5..c21392e3a 100644
--- a/packages/astro/src/transitions/router.ts
+++ b/packages/astro/src/transitions/router.ts
@@ -13,9 +13,14 @@ type Events = 'astro:page-load' | 'astro:after-swap';
// only update history entries that are managed by us
// leave other entries alone and do not accidently add state.
const persistState = (state: State) => history.state && history.replaceState(state, '');
-export const supportsViewTransitions = !!document.startViewTransition;
+
+const inBrowser = import.meta.env.SSR === false;
+
+export const supportsViewTransitions = inBrowser && !!document.startViewTransition;
+
export const transitionEnabledOnThisPage = () =>
- !!document.querySelector('[name="astro-view-transitions-enabled"]');
+ inBrowser && !!document.querySelector('[name="astro-view-transitions-enabled"]');
+
const samePage = (otherLocation: URL) =>
location.pathname === otherLocation.pathname && location.search === otherLocation.search;
const triggerEvent = (name: Events) => document.dispatchEvent(new Event(name));
@@ -40,21 +45,27 @@ const announce = () => {
60
);
};
+
const PERSIST_ATTR = 'data-astro-transition-persist';
-const parser = new DOMParser();
+
+let parser: DOMParser;
// The History API does not tell you if navigation is forward or back, so
// you can figure it using an index. On pushState the index is incremented so you
// can use that to determine popstate if going forward or back.
let currentHistoryIndex = 0;
-if (history.state) {
- // we reloaded a page with history state
- // (e.g. history navigation from non-transition page or browser reload)
- currentHistoryIndex = history.state.index;
- scrollTo({ left: history.state.scrollX, top: history.state.scrollY });
-} else if (transitionEnabledOnThisPage()) {
- history.replaceState({ index: currentHistoryIndex, scrollX, scrollY, intraPage: false }, '');
+
+if (inBrowser) {
+ if (history.state) {
+ // we reloaded a page with history state
+ // (e.g. history navigation from non-transition page or browser reload)
+ currentHistoryIndex = history.state.index;
+ scrollTo({ left: history.state.scrollX, top: history.state.scrollY });
+ } else if (transitionEnabledOnThisPage()) {
+ history.replaceState({ index: currentHistoryIndex, scrollX, scrollY, intraPage: false }, '');
+ }
}
+
const throttle = (cb: (...args: any[]) => any, delay: number) => {
let wait = false;
// During the waiting time additional events are lost.
@@ -336,6 +347,8 @@ async function transition(
toLocation = new URL(response.redirected);
}
+ parser ??= new DOMParser();
+
const newDocument = parser.parseFromString(response.html, response.mediaType);
// The next line might look like a hack,
// but it is actually necessary as noscript elements
@@ -372,7 +385,22 @@ async function transition(
}
}
+let navigateOnServerWarned = false;
+
export function navigate(href: string, options?: Options) {
+ if (inBrowser === false) {
+ if (!navigateOnServerWarned) {
+ // instantiate an error for the stacktrace to show to user.
+ const warning = new Error(
+ 'The view transtions client API was called during a server side render. This may be unintentional as the navigate() function is expected to be called in response to user interactions. Please make sure that your usage is correct.'
+ );
+ warning.name = 'Warning';
+ console.warn(warning);
+ navigateOnServerWarned = true;
+ }
+ return;
+ }
+
// not ours
if (!transitionEnabledOnThisPage()) {
location.href = href;
@@ -390,58 +418,61 @@ export function navigate(href: string, options?: Options) {
}
}
-if (supportsViewTransitions || getFallback() !== 'none') {
- addEventListener('popstate', (ev) => {
- if (!transitionEnabledOnThisPage() && ev.state) {
- // The current page doesn't have View Transitions enabled
- // but the page we navigate to does (because it set the state).
- // Do a full page refresh to reload the client-side router from the new page.
- // Scroll restauration will then happen during the reload when the router's code is re-executed
- if (history.scrollRestoration) {
- history.scrollRestoration = 'manual';
- }
- location.reload();
- return;
- }
-
- // History entries without state are created by the browser (e.g. for hash links)
- // Our view transition entries always have state.
- // Just ignore stateless entries.
- // The browser will handle navigation fine without our help
- if (ev.state === null) {
- if (history.scrollRestoration) {
- history.scrollRestoration = 'auto';
- }
- return;
- }
-
- // With the default "auto", the browser will jump to the old scroll position
- // before the ViewTransition is complete.
+function onPopState(ev: PopStateEvent) {
+ if (!transitionEnabledOnThisPage() && ev.state) {
+ // The current page doesn't have View Transitions enabled
+ // but the page we navigate to does (because it set the state).
+ // Do a full page refresh to reload the client-side router from the new page.
+ // Scroll restauration will then happen during the reload when the router's code is re-executed
if (history.scrollRestoration) {
history.scrollRestoration = 'manual';
}
+ location.reload();
+ return;
+ }
- const state: State = history.state;
- if (state.intraPage) {
- // this is non transition intra-page scrolling
- scrollTo(state.scrollX, state.scrollY);
- } else {
- const nextIndex = state.index;
- const direction: Direction = nextIndex > currentHistoryIndex ? 'forward' : 'back';
- currentHistoryIndex = nextIndex;
- transition(direction, new URL(location.href), {}, state);
+ // History entries without state are created by the browser (e.g. for hash links)
+ // Our view transition entries always have state.
+ // Just ignore stateless entries.
+ // The browser will handle navigation fine without our help
+ if (ev.state === null) {
+ if (history.scrollRestoration) {
+ history.scrollRestoration = 'auto';
}
- });
+ return;
+ }
- addEventListener('load', onPageLoad);
- // There's not a good way to record scroll position before a back button.
- // So the way we do it is by listening to scrollend if supported, and if not continuously record the scroll position.
- const updateState = () => {
- persistState({ ...history.state, scrollX, scrollY });
- };
+ // With the default "auto", the browser will jump to the old scroll position
+ // before the ViewTransition is complete.
+ if (history.scrollRestoration) {
+ history.scrollRestoration = 'manual';
+ }
- if ('onscrollend' in window) addEventListener('scrollend', updateState);
- else addEventListener('scroll', throttle(updateState, 300));
-
- markScriptsExec();
+ const state: State = history.state;
+ if (state.intraPage) {
+ // this is non transition intra-page scrolling
+ scrollTo(state.scrollX, state.scrollY);
+ } else {
+ const nextIndex = state.index;
+ const direction: Direction = nextIndex > currentHistoryIndex ? 'forward' : 'back';
+ currentHistoryIndex = nextIndex;
+ transition(direction, new URL(location.href), {}, state);
+ }
+}
+
+if (inBrowser) {
+ if (supportsViewTransitions || getFallback() !== 'none') {
+ addEventListener('popstate', onPopState);
+ addEventListener('load', onPageLoad);
+ // There's not a good way to record scroll position before a back button.
+ // So the way we do it is by listening to scrollend if supported, and if not continuously record the scroll position.
+ const updateState = () => {
+ persistState({ ...history.state, scrollX, scrollY });
+ };
+
+ if ('onscrollend' in window) addEventListener('scrollend', updateState);
+ else addEventListener('scroll', throttle(updateState, 300));
+
+ markScriptsExec();
+ }
}